# Generated by ariadne-codegen
# Source: ./documents

from typing import List, Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class DeleteMedicalStudies(BaseModel):
    delete_medical_studies: Optional[
        List[Optional["DeleteMedicalStudiesDeleteMedicalStudies"]]
    ] = Field(alias="deleteMedicalStudies")


class DeleteMedicalStudiesDeleteMedicalStudies(BaseModel):
    id: str
    state: EntityState


DeleteMedicalStudies.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Any, List, Optional

from pydantic import Field

from .base_model import BaseModel


class QueryMedicalProcedures(BaseModel):
    medical_procedures: Optional["QueryMedicalProceduresMedicalProcedures"] = Field(
        alias="medicalProcedures"
    )


class QueryMedicalProceduresMedicalProcedures(BaseModel):
    results: Optional[List[Optional["QueryMedicalProceduresMedicalProceduresResults"]]]


class QueryMedicalProceduresMedicalProceduresResults(BaseModel):
    id: str
    name: str
    alternate_names: Optional[List[Optional[str]]] = Field(alias="alternateNames")
    creation_date: Any = Field(alias="creationDate")
    thing: Optional[str]
    relevance: Optional[float]


QueryMedicalProcedures.model_rebuild()
QueryMedicalProceduresMedicalProcedures.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Any, List, Optional

from pydantic import Field

from .base_model import BaseModel


class GetOrganization(BaseModel):
    organization: Optional["GetOrganizationOrganization"]


class GetOrganizationOrganization(BaseModel):
    id: str
    name: str
    alternate_names: Optional[List[Optional[str]]] = Field(alias="alternateNames")
    creation_date: Any = Field(alias="creationDate")
    thing: Optional[str]
    relevance: Optional[float]
    address: Optional["GetOrganizationOrganizationAddress"]
    founding_date: Optional[Any] = Field(alias="foundingDate")
    industries: Optional[List[Optional[str]]]
    revenue: Optional[Any]
    revenue_currency: Optional[str] = Field(alias="revenueCurrency")
    investment: Optional[Any]
    investment_currency: Optional[str] = Field(alias="investmentCurrency")


class GetOrganizationOrganizationAddress(BaseModel):
    street_address: Optional[str] = Field(alias="streetAddress")
    city: Optional[str]
    region: Optional[str]
    country: Optional[str]
    postal_code: Optional[str] = Field(alias="postalCode")


GetOrganization.model_rebuild()
GetOrganizationOrganization.model_rebuild()
